@@ -26,32 +26,23 @@ package fa_conf;
 #
 ################################################################
 
-#################################################################
-#
-#  *** This functionality is NOT yet implemented. ***
-#
-#################################################################
-
 require Exporter;
 use warnings;
 our @ISA     = qw(Exporter);
-our @EXPORT  = qw(@Maps);
+our @EXPORT  = qw(@editor);
 our $VERSION = 1.00;
 
-@Maps = (
 #################################################################
 ##  Do NOT alter code ABOVE this block.
 #################################################################
 ##  -------------------------------------------------------------
-##  ADD CONFIGURATION BLOCKS HERE:
+##  ADD SETTINGS HERE:
 ##  -------------------------------------------------------------
 
-
-
+# $editor = '';
 
 #################################################################
 ##  Do NOT alter code BELOW this block.
 #################################################################
-);
 1;
 
